package com.wastedpotential {
	import net.flashpunk.graphics.Image;
	import net.flashpunk.utils.Input;
	import net.flashpunk.utils.Key;
	import net.flashpunk.graphics.Spritemap;
	import net.flashpunk.Entity;
	
	public class Player extends DebugEntity {
		
		[Embed(source = '../../assets/blob_sprite.gif')] private const SPRITE_GUY:Class;
		public var blob:Spritemap = new Spritemap(SPRITE_GUY, 32, 32);

		private var isRunning:Boolean = false;
		private var isJumping:Boolean = false;
		private var ySpeed:Number = 0;
		private var xSpeed:Number = 0;
		private var numPowerups:int = 0;
				
		public function Player() {
			//trace("Player :: CONSTRUCTOR");
			
			blob.add("stand", [0, 1, 2, 1], 10, true);
			blob.add("run", [3, 4, 5, 4], 10, true);
			blob.add("jump", [5], 12, true);
			graphic = blob;
			width = 32; //hitbox width
			height = 32; //hitbox height
			
			//set up key controls:
			Input.define("keyLeft", Key.A, Key.LEFT);
			Input.define("keyRight", Key.S, Key.RIGHT);	
			Input.define("keyJump", Key.SPACE);
		}
		
		//- called on every frame to update the Entity state
		override public function update():void {
			//trace("Player :: update");
			
			// Assign any possible collided Item Entity to a temporary var.
			var powerup:Item = collide("item", x, y) as Item;
			// Check if powerup has a value (true if an Item was collided with).
			if (powerup) {
				powerup.destroy(); // Call the Item's destroy() function to remove it from the screen
				numPowerups++; //add it to the player's inventory
			}
			
			isRunning = false;
			if (Input.check("keyLeft")) { 
				xSpeed -= Settings.acceleration; 
				xSpeed = Math.max( -1 * Settings.maxXSpeed, xSpeed);
				blob.scaleX = -1; //reverse the image
				//blob.x = blob.width; //correct the image position
				isRunning = true;
			}
			else if (Input.check("keyRight")) { 
				xSpeed += Settings.acceleration; 
				xSpeed = Math.min(Settings.maxXSpeed, xSpeed);
				blob.scaleX = 1; //show image forward
				//blob.x = 0; //correct the image position
				isRunning = true;
			}
			else {
				if (xSpeed >= Settings.acceleration) {
					xSpeed -= Settings.acceleration;
				}
				else if (xSpeed <= -Settings.acceleration) {
					xSpeed += Settings.acceleration;
				}
				else {
					xSpeed = 0;
				}
			}
			if (Input.pressed("keyJump") && !isJumping) {
				ySpeed -= Settings.jumpVelocity;
				isJumping = true;
			}
			
			//make sure gravity is always pulling player down:
			ySpeed += Settings.gravity;
			
			//render the correct graphic:
			if (isJumping) {
				blob.play("jump");
			}
			else if (isRunning) {
				blob.play("run");
			}
			else {
				blob.play("stand");
			}
			
			moveBy(xSpeed, ySpeed, "wall_tile"); //this auto-checks for collisions with wall tiles
			
		}
		
		//- handles collisions with the wall tiles in the y-direction
		override public function moveCollideX(e:Entity):Boolean {
			//trace("Player :: moveCollideX");
			xSpeed = 0; //stop x-motion
			return true;
		}

		//- handles collisions with the wall tiles in the y-direction
		override public function moveCollideY(e:Entity):Boolean {
			//trace("Player :: moveCollideY");
			ySpeed = 0; //stop y-motion
			if (e.y > this.y) { //if colliding with something BELOW the player
				isJumping = false; //reset jumping flag
			}
			return true;
		}
		
	} //end class
} //end package