package com.wastedpotential {
	import com.bit101.components.FPSMeter;
	import com.bit101.components.InputText;
	import com.bit101.components.Label;
	import com.bit101.components.Panel;
	import com.bit101.components.Text;
	import com.bit101.components.Window;
	import com.bit101.components.PushButton;
	import net.flashpunk.utils.Input;
	import net.flashpunk.utils.Key;
	import flash.events.Event;
	import flash.events.MouseEvent;
	
	//- sets up the minimalcomps testing panel
	public class TestingGUI extends Panel {
		
		private var fpsMeter:FPSMeter;
		private var hitboxButton:PushButton;
		private var gravityLabel:Label;
		private var gravitySetter:InputText;
		private var jumpVelLabel:Label;
		private var jumpVelSetter:InputText;
		private var maxXVelLabel:Label;
		private var maxXVelSetter:InputText;
		private var xAccLabel:Label;
		private var xAccSetter:InputText;
		
		//- set up the testing panel
		public function TestingGUI() {
			//trace("TestingGUI :: CONSTRUCTOR");
			
			//set up key controls to match the Player class (for handling textfield focus)
			Input.define("keyLeft", Key.A, Key.LEFT);
			Input.define("keyRight", Key.S, Key.RIGHT);	
			Input.define("keyJump", Key.SPACE);
			addEventListener(Event.ENTER_FRAME, update);
			
			super(null, 0, 0); 
			width = 130;
			height = 160;
			
			fpsMeter = new FPSMeter(this, 5, 5, "FPS = ");
			fpsMeter.start();
			
			hitboxButton = new PushButton (this, 5, 30, "Show Hitboxes", onHitboxBuClick);
			setHitboxButtonLabel();
			
			gravityLabel = new Label(this, 5, 55, "Gravity");
			gravitySetter = new InputText(this, 75, 55, String(Settings.gravity), onGravityChange);
			gravitySetter.width = 40;
			gravitySetter.height = 22;
			
			jumpVelLabel = new Label(this, 5, 80, "Jump Velocity");
			jumpVelSetter = new InputText(this, 75, 80, String(Settings.jumpVelocity), onJumpVelChange);
			jumpVelSetter.width = 40;
			jumpVelSetter.height = 22;
			
			/*
			maxXVelLabel = new Label(this, 5, 105, "Max X Velocity");
			maxXVelSetter = new InputText(this, 75, 105, String(Settings.maxXSpeed), onMaxXVelChange);
			maxXVelSetter.width = 40;
			maxXVelSetter.height = 22;
			
			xAccLabel = new Label(this, 5, 130, "X Acceleration");
			xAccSetter = new InputText(this, 75, 130, String(Settings.acceleration), onXAccChange);
			xAccSetter.width = 40;
			xAccSetter.height = 22;
			*/
		}
		
		//- listens for keypresses and returns focus to flash stage.
		//- This prevents bugginess with the text fields
		private function update(e:Event):void {
			//trace("TestingGUI :: update");
			if (Input.check("keyLeft") || Input.check("keyRight") || Input.pressed("keyJump")) {
				if (stage) {
					stage.focus = null;
				}
			}
		}
		
		//- button handler - toggles hitbox visibility
		private function onHitboxBuClick(e:MouseEvent):void {
			//trace("TestingGUI :: onHitboxBuClick");
			Settings.showHitboxes = !Settings.showHitboxes;
			setHitboxButtonLabel();
		}
		
		//- set hitbox toggle button label
		private function setHitboxButtonLabel():void {
			//trace("TestingGUI :: setHitboxButtonLabel");
			if (Settings.showHitboxes) {
				hitboxButton.label = "Hide Hit Boxes";
			}
			else {
				hitboxButton.label = "Show Hit Boxes";
			}
		}
		
		//- input handler - changes the game gravity
		private function onGravityChange(e:Event):void {
			//trace("TestingGUI :: onGravityChange");
			Settings.gravity = Number(gravitySetter.text);
		}
		
		//- input handler - changes the players jump y-velocity
		private function onJumpVelChange(e:Event):void {
			//trace("TestingGUI :: onJumpVelChange");
			Settings.jumpVelocity = Number(jumpVelSetter.text);
		}
		
		//- input handler - changes the players maximum x-velocity
		private function onMaxXVelChange(e:Event):void {
			//trace("TestingGUI :: onMaxXVelChange");
			Settings.maxXSpeed = Number(maxXVelSetter.text);
		}
		
		//- input handler - changes the players x-acceleration
		private function onXAccChange(e:Event):void {
			//trace("TestingGUI :: onXAccChange");
			Settings.acceleration = Number(xAccSetter.text);
		}
		
	} //end class
} //end package